@@ -15,9 +15,25 @@ Usage (module):
     import jc.parsers.airport
     result = jc.parsers.airport.parse(airport_command_output)
 
-Compatibility:
+Schema:
 
-    'darwin'
+    {
+      "agrctlrssi":        integer,
+      "agrextrssi":        integer,
+      "agrctlnoise":       integer,
+      "agrextnoise":       integer,
+      "state":             string,
+      "op_mode":           string,
+      "lasttxrate":        integer,
+      "maxrate":           integer,
+      "lastassocstatus":   integer,
+      "802_11_auth":       string,
+      "link_auth":         string,
+      "bssid":             string,
+      "ssid":              string,
+      "mcs":               integer,
+      "channel":           string
+    }
 
 Examples:
 
@@ -63,7 +79,8 @@ import jc.utils
 
 
 class info():
-    version = '1.1'
+    """Provides parser metadata (version, author, etc.)"""
+    version = '1.2'
     description = '`airport -I` command parser'
     author = 'Kelly Brazil'
     author_email = 'kellyjonbrazil@gmail.com'
@@ -77,7 +94,7 @@ class info():
 __version__ = info.version
 
 
-def process(proc_data):
+def _process(proc_data):
     """
     Final processing to conform to the schema.
 
@@ -87,25 +104,7 @@ def process(proc_data):
 
     Returns:
 
-        Dictionary. Structured data with the following schema:
-
-        {
-          "agrctlrssi":        integer,
-          "agrextrssi":        integer,
-          "agrctlnoise":       integer,
-          "agrextnoise":       integer,
-          "state":             string,
-          "op_mode":           string,
-          "lasttxrate":        integer,
-          "maxrate":           integer,
-          "lastassocstatus":   integer,
-          "802_11_auth":       string,
-          "link_auth":         string,
-          "bssid":             string,
-          "ssid":              string,
-          "mcs":               integer,
-          "channel":           string
-        }
+        Dictionary. Structured data to conform to the schema.
     """
     # integer changes
     int_list = ['agrctlrssi', 'agrextrssi', 'agrctlnoise', 'agrextnoise',
@@ -148,4 +147,4 @@ def parse(data, raw=False, quiet=False):
     if raw:
         return raw_output
     else:
-        return process(raw_output)
+        return _process(raw_output)
