@@ -15,9 +15,21 @@ Usage (module):
     import jc.parsers.airport_s
     result = jc.parsers.airport_s.parse(airport_s_command_output)
 
-Compatibility:
+Schema:
 
-    'darwin'
+    [
+      {
+        "ssid":         string,
+        "bssid":        string,
+        "rssi":         integer,
+        "channel":      string,
+        "ht":           boolean,
+        "cc":           string,
+        "security": [
+                        string,
+        ]
+      }
+    ]
 
 Examples:
 
@@ -96,7 +108,8 @@ import jc.parsers.universal
 
 
 class info():
-    version = '1.2'
+    """Provides parser metadata (version, author, etc.)"""
+    version = '1.3'
     description = '`airport -s` command parser'
     author = 'Kelly Brazil'
     author_email = 'kellyjonbrazil@gmail.com'
@@ -110,7 +123,7 @@ class info():
 __version__ = info.version
 
 
-def process(proc_data):
+def _process(proc_data):
     """
     Final processing to conform to the schema.
 
@@ -120,20 +133,7 @@ def process(proc_data):
 
     Returns:
 
-        List of Dictionaries. Structured data with the following schema:
-        [
-          {
-            "ssid":      string,
-            "bssid":     string,
-            "rssi":      integer,
-            "channel":   string,
-            "ht":        boolean,
-            "cc":        string,
-            "security": [
-                         string,
-            ]
-          }
-        ]
+        List of Dictionaries. Structured data to conform to the schema.
     """
     for entry in proc_data:
 
@@ -193,4 +193,4 @@ def parse(data, raw=False, quiet=False):
     if raw:
         return raw_output
     else:
-        return process(raw_output)
+        return _process(raw_output)
