@@ -13,9 +13,24 @@ Usage (module):
     import jc.parsers.df
     result = jc.parsers.df.parse(df_command_output)
 
-Compatibility:
+Schema:
 
-    'linux', 'darwin', 'freebsd'
+    [
+      {
+        "filesystem":        string,
+        "size":              string,
+        "1k_blocks":         integer,
+        "512_blocks":        integer,
+        "used":              integer,
+        "available":         integer,
+        "capacity_percent":  integer,
+        "ifree":             integer,
+        "iused":             integer,
+        "use_percent":       integer,
+        "iused_percent":     integer,
+        "mounted_on":        string
+      }
+    ]
 
 Examples:
 
@@ -82,7 +97,8 @@ import jc.parsers.universal
 
 
 class info():
-    version = '1.5'
+    """Provides parser metadata (version, author, etc.)"""
+    version = '1.6'
     description = '`df` command parser'
     author = 'Kelly Brazil'
     author_email = 'kellyjonbrazil@gmail.com'
@@ -95,7 +111,7 @@ class info():
 __version__ = info.version
 
 
-def process(proc_data):
+def _process(proc_data):
     """
     Final processing to conform to the schema.
 
@@ -105,24 +121,7 @@ def process(proc_data):
 
     Returns:
 
-        List of Dictionaries. Structured data with the following schema:
-
-        [
-          {
-            "filesystem":        string,
-            "size":              string,
-            "1k_blocks":         integer,
-            "512_blocks":        integer,
-            "used":              integer,
-            "available":         integer,
-            "capacity_percent":  integer,
-            "ifree":             integer,
-            "iused":             integer,
-            "use_percent":       integer,
-            "iused_percent":     integer,
-            "mounted_on":        string
-          }
-        ]
+        List of Dictionaries. Structured data to conform to the schema:
     """
 
     for entry in proc_data:
@@ -208,4 +207,4 @@ def parse(data, raw=False, quiet=False):
     if raw:
         return raw_output
     else:
-        return process(raw_output)
+        return _process(raw_output)
