@@ -10,24 +10,34 @@ The `epoch` calculated timestamp field is naive (i.e. based on the local time of
 
 Usage (cli):
 
-    $ dir | jc --dir
+    C:> dir | jc --dir
 
     or
 
-    $ jc dir
+    C:> jc dir
 
 Usage (module):
 
     import jc.parsers.dir
     result = jc.parsers.dir.parse(dir_command_output)
 
-Compatibility:
+Schema:
 
-    'win32'
+    [
+      {
+        "date":         string,
+        "time":         string,
+        "epoch":        integer,    # naive timestamp
+        "dir":          boolean,
+        "size":         integer,
+        "filename:      string,
+        "parent":       string
+      }
+    ]
 
 Examples:
 
-    $ dir | jc --dir -p
+    C:> dir | jc --dir -p
     [
       {
         "date": "03/24/2021",
@@ -68,7 +78,7 @@ Examples:
       ...
     ]
 
-    $ dir | jc --dir -p -r
+    C:> dir | jc --dir -p -r
     [
       {
         "date": "03/24/2021",
@@ -110,7 +120,8 @@ import jc.utils
 
 
 class info():
-    version = '1.0'
+    """Provides parser metadata (version, author, etc.)"""
+    version = '1.1'
     description = '`dir` command parser'
     author = 'Rasheed Elsaleh'
     author_email = 'rasheed@rebelliondefense.com'
@@ -123,7 +134,7 @@ class info():
 __version__ = info.version
 
 
-def process(proc_data):
+def _process(proc_data):
     """
     Final processing to conform to the schema.
 
@@ -133,19 +144,7 @@ def process(proc_data):
 
     Returns:
 
-        List of Dictionaries. Structured data with the following schema:
-
-        [
-          {
-            "date":         string,
-            "time":         string,
-            "epoch":        integer,    # naive timestamp
-            "dir":          boolean,
-            "size":         integer,
-            "filename:      string,
-            "parent":       string
-          }
-        ]
+        List of Dictionaries. Structured data to conform to the schema.
     """
     for entry in proc_data:
         # add timestamps
@@ -216,4 +215,4 @@ def parse(data, raw=False, quiet=False):
     if raw:
         return raw_output
     else:
-        return process(raw_output)
+        return _process(raw_output)
