@@ -13,9 +13,19 @@ Usage (module):
     import jc.parsers.free
     result = jc.parsers.free.parse(free_command_output)
 
-Compatibility:
+Schema:
 
-    'linux'
+    [
+      {
+        "type":         string,
+        "total":        integer,
+        "used":         integer,
+        "free":         integer,
+        "shared":       integer,
+        "buff_cache":   integer,
+        "available":    integer
+      }
+    ]
 
 Examples:
 
@@ -62,7 +72,8 @@ import jc.parsers.universal
 
 
 class info():
-    version = '1.2'
+    """Provides parser metadata (version, author, etc.)"""
+    version = '1.3'
     description = '`free` command parser'
     author = 'Kelly Brazil'
     author_email = 'kellyjonbrazil@gmail.com'
@@ -75,7 +86,7 @@ class info():
 __version__ = info.version
 
 
-def process(proc_data):
+def _process(proc_data):
     """
     Final processing to conform to the schema.
 
@@ -85,19 +96,7 @@ def process(proc_data):
 
     Returns:
 
-        List of Dictionaries. Structured data with the following schema:
-
-        [
-          {
-            "type":         string,
-            "total":        integer,
-            "used":         integer,
-            "free":         integer,
-            "shared":       integer,
-            "buff_cache":   integer,
-            "available":    integer
-          }
-        ]
+        List of Dictionaries. Structured data to conform to the schema.
     """
 
     for entry in proc_data:
@@ -147,4 +146,4 @@ def parse(data, raw=False, quiet=False):
     if raw:
         return raw_output
     else:
-        return process(raw_output)
+        return _process(raw_output)
