@@ -9,9 +9,18 @@ Usage (module):
     import jc.parsers.group
     result = jc.parsers.group.parse(group_file_output)
 
-Compatibility:
+Schema:
 
-    'linux', 'darwin', 'aix', 'freebsd'
+    [
+      {
+        "group_name":    string,
+        "password":      string,
+        "gid":           integer,
+        "members": [
+                         string
+        ]
+      }
+    ]
 
 Examples:
 
@@ -99,7 +108,8 @@ import jc.utils
 
 
 class info():
-    version = '1.1'
+    """Provides parser metadata (version, author, etc.)"""
+    version = '1.2'
     description = '`/etc/group` file parser'
     author = 'Kelly Brazil'
     author_email = 'kellyjonbrazil@gmail.com'
@@ -112,7 +122,7 @@ class info():
 __version__ = info.version
 
 
-def process(proc_data):
+def _process(proc_data):
     """
     Final processing to conform to the schema.
 
@@ -122,18 +132,7 @@ def process(proc_data):
 
     Returns:
 
-        List of Dictionaries. Structured data with the following schema:
-
-        [
-          {
-            "group_name":    string,
-            "password":      string,
-            "gid":           integer,
-            "members": [
-                             string
-            ]
-          }
-        ]
+        List of Dictionaries. Structured data to conform to the schema.
     """
     for entry in proc_data:
         int_list = ['gid']
@@ -193,4 +192,4 @@ def parse(data, raw=False, quiet=False):
     if raw:
         return raw_output
     else:
-        return process(raw_output)
+        return _process(raw_output)
