@@ -15,9 +15,28 @@ Usage (module):
     import jc.parsers.iptables
     result = jc.parsers.iptables.parse(iptables_command_output)
 
-Compatibility:
+Schema:
 
-    'linux'
+    [
+      {
+        "chain":                string,
+        "rules": [
+          {
+            "num"               integer,
+            "pkts":             integer,
+            "bytes":            integer,  # converted based on suffix
+            "target":           string,
+            "prot":             string,
+            "opt":              string,   # "--" = Null
+            "in":               string,
+            "out":              string,
+            "source":           string,
+            "destination":      string,
+            "options":          string
+          }
+        ]
+      }
+    ]
 
 Examples:
 
@@ -143,7 +162,8 @@ import jc.utils
 
 
 class info():
-    version = '1.4'
+    """Provides parser metadata (version, author, etc.)"""
+    version = '1.5'
     description = '`iptables` command parser'
     author = 'Kelly Brazil'
     author_email = 'kellyjonbrazil@gmail.com'
@@ -156,7 +176,7 @@ class info():
 __version__ = info.version
 
 
-def process(proc_data):
+def _process(proc_data):
     """
     Final processing to conform to the schema.
 
@@ -166,28 +186,7 @@ def process(proc_data):
 
     Returns:
 
-        List of Dictionaries. Structured data with the following schema:
-
-        [
-          {
-            "chain":                string,
-            "rules": [
-              {
-                "num"               integer,
-                "pkts":             integer,
-                "bytes":            integer,  # converted based on suffix
-                "target":           string,
-                "prot":             string,
-                "opt":              string,   # "--" = Null
-                "in":               string,
-                "out":              string,
-                "source":           string,
-                "destination":      string,
-                "options":          string
-              }
-            ]
-          }
-        ]
+        List of Dictionaries. Structured data to conform to the schema.
     """
     for entry in proc_data:
         for rule in entry['rules']:
@@ -289,4 +288,4 @@ def parse(data, raw=False, quiet=False):
     if raw:
         return raw_output
     else:
-        return process(raw_output)
+        return _process(raw_output)
