@@ -24,9 +24,22 @@ Usage (module):
     import jc.parsers.ls
     result = jc.parsers.ls.parse(ls_command_output)
 
-Compatibility:
+Schema:
 
-    'linux', 'darwin', 'cygwin', 'aix', 'freebsd'
+    [
+      {
+        "filename":     string,
+        "flags":        string,
+        "links":        integer,
+        "parent":       string,
+        "owner":        string,
+        "group":        string,
+        "size":         integer,
+        "date":         string,
+        "epoch":        integer,     # naive timestamp if date field exists and can be converted
+        "epoch_utc":    integer      # timezone aware timestamp if date field is in UTC and can be converted
+      }
+    ]
 
 Examples:
 
@@ -38,12 +51,6 @@ Examples:
       {
         "filename": "arch"
       },
-      {
-        "filename": "awk"
-      },
-      {
-        "filename": "base64"
-      },
       ...
     ]
 
@@ -68,15 +75,6 @@ Examples:
         "size": 62744,
         "date": "Aug 8 16:14"
       },
-      {
-        "filename": "arch",
-        "flags": "-rwxr-xr-x.",
-        "links": 1,
-        "owner": "root",
-        "group": "root",
-        "size": 33080,
-        "date": "Aug 19 23:25"
-      },
       ...
     ]
 
@@ -101,63 +99,16 @@ Examples:
         "size": "33080",
         "date": "Aug 19 23:25"
       },
-      {
-        "filename": "awk",
-        "link_to": "gawk",
-        "flags": "lrwxrwxrwx.",
-        "links": "1",
-        "owner": "root",
-        "group": "root",
-        "size": "4",
-        "date": "Aug 15 10:53"
-      },
-      {
-        "filename": "base64",
-        "flags": "-rwxr-xr-x.",
-        "links": "1",
-        "owner": "root",
-        "group": "root",
-        "size": "37360",
-        "date": "Aug 19 23:25"
-      },
-      {
-        "filename": "basename",
-        "flags": "-rwxr-xr-x.",
-        "links": "1",
-        "owner": "root",
-        "group": "root",
-        "size": "29032",
-        "date": "Aug 19 23:25"
-      },
-      {
-        "filename": "bash",
-        "flags": "-rwxr-xr-x.",
-        "links": "1",
-        "owner": "root",
-        "group": "root",
-        "size": "964600",
-        "date": "Aug 8 05:06"
-      },
       ...
     ]
-
-    $ ls -l /usr/bin | jc --ls | jq '.[] | select(.size > 50000000)'
-    {
-      "filename": "emacs",
-      "flags": "-r-xr-xr-x",
-      "links": 1,
-      "owner": "root",
-      "group": "wheel",
-      "size": 117164432,
-      "date": "May 3 2019"
-    }
 """
 import re
 import jc.utils
 
 
 class info():
-    version = '1.7'
+    """Provides parser metadata (version, author, etc.)"""
+    version = '1.8'
     description = '`ls` command parser'
     author = 'Kelly Brazil'
     author_email = 'kellyjonbrazil@gmail.com'
@@ -170,7 +121,7 @@ class info():
 __version__ = info.version
 
 
-def process(proc_data):
+def _process(proc_data):
     """
     Final processing to conform to the schema.
 
@@ -180,22 +131,7 @@ def process(proc_data):
 
     Returns:
 
-        List of Dictionaries. Structured data with the following schema:
-
-        [
-          {
-            "filename":     string,
-            "flags":        string,
-            "links":        integer,
-            "parent":       string,
-            "owner":        string,
-            "group":        string,
-            "size":         integer,
-            "date":         string,
-            "epoch":        integer,     # naive timestamp if date field exists and can be converted
-            "epoch_utc":    integer      # timezone aware timestamp if date field is in UTC and can be converted
-          }
-        ]
+        List of Dictionaries. Structured data to conform to the schema.
     """
     for entry in proc_data:
         int_list = ['links', 'size']
@@ -337,4 +273,4 @@ def parse(data, raw=False, quiet=False):
     if raw:
         return raw_output
     else:
-        return process(raw_output)
+        return _process(raw_output)
