@@ -13,9 +13,18 @@ Usage (module):
     import jc.parsers.lsmod
     result = jc.parsers.lsmod.parse(lsmod_command_output)
 
-Compatibility:
+Schema:
 
-    'linux'
+    [
+      {
+        "module":     string,
+        "size":       integer,
+        "used":       integer,
+        "by": [
+                      string
+        ]
+      }
+    ]
 
 Examples:
 
@@ -116,7 +125,8 @@ import jc.parsers.universal
 
 
 class info():
-    version = '1.3'
+    """Provides parser metadata (version, author, etc.)"""
+    version = '1.4'
     description = '`lsmod` command parser'
     author = 'Kelly Brazil'
     author_email = 'kellyjonbrazil@gmail.com'
@@ -129,7 +139,7 @@ class info():
 __version__ = info.version
 
 
-def process(proc_data):
+def _process(proc_data):
     """
     Final processing to conform to the schema.
 
@@ -139,18 +149,7 @@ def process(proc_data):
 
     Returns:
 
-        List of Dictionaries. Structured data with the following schema:
-
-        [
-          {
-            "module": string,
-            "size":   integer,
-            "used":   integer,
-            "by": [
-                      string
-            ]
-          }
-        ]
+        List of Dictionaries. Structured data to conform to the schema.
     """
     for entry in proc_data:
         # integer changes
@@ -199,4 +198,4 @@ def parse(data, raw=False, quiet=False):
     if raw:
         return raw_output
     else:
-        return process(raw_output)
+        return _process(raw_output)
