@@ -13,9 +13,22 @@ Usage (module):
     import jc.parsers.lsof
     result = jc.parsers.lsof.parse(lsof_command_output)
 
-Compatibility:
+Schema:
 
-    'linux'
+    [
+      {
+        "command":    string,
+        "pid":        integer,
+        "tid":        integer,
+        "user":       string,
+        "fd":         string,
+        "type":       string,
+        "device":     string,
+        "size_off":   integer,
+        "node":       integer,
+        "name":       string
+      }
+    ]
 
 Examples:
 
@@ -106,7 +119,8 @@ import jc.parsers.universal
 
 
 class info():
-    version = '1.2'
+    """Provides parser metadata (version, author, etc.)"""
+    version = '1.3'
     description = '`lsof` command parser'
     author = 'Kelly Brazil'
     author_email = 'kellyjonbrazil@gmail.com'
@@ -119,7 +133,7 @@ class info():
 __version__ = info.version
 
 
-def process(proc_data):
+def _process(proc_data):
     """
     Final processing to conform to the schema.
 
@@ -129,22 +143,7 @@ def process(proc_data):
 
     Returns:
 
-        List of Dictionaries. Structured data with the following schema:
-
-        [
-          {
-            "command":    string,
-            "pid":        integer,
-            "tid":        integer,
-            "user":       string,
-            "fd":         string,
-            "type":       string,
-            "device":     string,
-            "size_off":   integer,
-            "node":       integer,
-            "name":       string
-          }
-        ]
+        List of Dictionaries. Structured data to conform to the schema.
     """
     for entry in proc_data:
         # integer changes
@@ -191,4 +190,4 @@ def parse(data, raw=False, quiet=False):
     if raw:
         return raw_output
     else:
-        return process(raw_output)
+        return _process(raw_output)
