@@ -13,9 +13,23 @@ Usage (module):
     import jc.parsers.ntpq
     result = jc.parsers.ntpq.parse(ntpq_command_output)
 
-Compatibility:
+Schema:
 
-    'linux', 'freebsd'
+    [
+      {
+        "state":            string,        # space/~ converted to null
+        "remote":           string,
+        "refid":            string,
+        "st":               integer,
+        "t":                string,
+        "when":             integer,       # - converted to null
+        "poll":             integer,
+        "reach":            integer,
+        "delay":            float,
+        "offset":           float,
+        "jitter":           float
+      },
+    ]
 
 Examples:
 
@@ -192,7 +206,8 @@ import jc.parsers.universal
 
 
 class info():
-    version = '1.3'
+    """Provides parser metadata (version, author, etc.)"""
+    version = '1.4'
     description = '`ntpq -p` command parser'
     author = 'Kelly Brazil'
     author_email = 'kellyjonbrazil@gmail.com'
@@ -205,7 +220,7 @@ class info():
 __version__ = info.version
 
 
-def process(proc_data):
+def _process(proc_data):
     """
     Final processing to conform to the schema.
 
@@ -215,24 +230,7 @@ def process(proc_data):
 
     Returns:
 
-        List of Dictionaries. Structured data with the following schema:
-
-        [
-          {
-            "state":            string,        # space/~ converted to null
-            "remote":           string,
-            "refid":            string,
-            "st":               integer,
-            "t":                string,
-            "when":             integer,       # - converted to null
-            "poll":             integer,
-            "reach":            integer,
-            "delay":            float,
-            "offset":           float,
-            "jitter":           float
-          },
-        ]
-
+        List of Dictionaries. Structured data to conform to the schema.
     """
     for entry in proc_data:
 
@@ -305,4 +303,4 @@ def parse(data, raw=False, quiet=False):
     if raw:
         return raw_output
     else:
-        return process(raw_output)
+        return _process(raw_output)
