@@ -17,9 +17,29 @@ Usage (module):
     import jc.parsers.ps
     result = jc.parsers.ps.parse(ps_command_output)
 
-Compatibility:
+Schema:
 
-    'linux', 'darwin', 'cygwin', 'aix', 'freebsd'
+    [
+      {
+        "uid":           string,
+        "pid":           integer,
+        "ppid":          integer,
+        "c":             integer,
+        "stime":         string,
+        "tty":           string,    # ? or ?? = Null
+        "tt":            string,    # ?? = Null
+        "time":          string,
+        "cmd":           string,
+        "user":          string,
+        "cpu_percent":   float,
+        "mem_percent":   float,
+        "vsz":           integer,
+        "rss":           integer,
+        "stat":          string,
+        "start":         string,
+        "command":       string
+      }
+    ]
 
 Examples:
 
@@ -186,7 +206,8 @@ import jc.parsers.universal
 
 
 class info():
-    version = '1.3'
+    """Provides parser metadata (version, author, etc.)"""
+    version = '1.4'
     description = '`ps` command parser'
     author = 'Kelly Brazil'
     author_email = 'kellyjonbrazil@gmail.com'
@@ -199,7 +220,7 @@ class info():
 __version__ = info.version
 
 
-def process(proc_data):
+def _process(proc_data):
     """
     Final processing to conform to the schema.
 
@@ -209,29 +230,7 @@ def process(proc_data):
 
     Returns:
 
-        List of Dictionaries. Structured data with the following schema:
-
-        [
-          {
-            "uid":           string,
-            "pid":           integer,
-            "ppid":          integer,
-            "c":             integer,
-            "stime":         string,
-            "tty":           string,    # ? or ?? = Null
-            "tt":            string,    # ?? = Null
-            "time":          string,
-            "cmd":           string,
-            "user":          string,
-            "cpu_percent":   float,
-            "mem_percent":   float,
-            "vsz":           integer,
-            "rss":           integer,
-            "stat":          string,
-            "start":         string,
-            "command":       string
-          }
-        ]
+        List of Dictionaries. Structured data to conform to the schema.
     """
     for entry in proc_data:
         # change key name '%cpu' to 'cpu_percent'
@@ -301,4 +300,4 @@ def parse(data, raw=False, quiet=False):
     if raw:
         return raw_output
     else:
-        return process(raw_output)
+        return _process(raw_output)
