@@ -13,9 +13,26 @@ Usage (module):
     import jc.parsers.route
     result = jc.parsers.route.parse(route_command_output)
 
-Compatibility:
+Schema:
 
-    'linux'
+    [
+      {
+        "destination":     string,
+        "gateway":         string,
+        "genmask":         string,
+        "flags":           string,
+        "flags_pretty": [
+                           string,
+        ]
+        "metric":          integer,
+        "ref":             integer,
+        "use":             integer,
+        "mss":             integer,
+        "window":          integer,
+        "irtt":            integer,
+        "iface":           string
+      }
+    ]
 
 Examples:
 
@@ -93,7 +110,8 @@ import jc.parsers.universal
 
 
 class info():
-    version = '1.4'
+    """Provides parser metadata (version, author, etc.)"""
+    version = '1.5'
     description = '`route` command parser'
     author = 'Kelly Brazil'
     author_email = 'kellyjonbrazil@gmail.com'
@@ -106,7 +124,7 @@ class info():
 __version__ = info.version
 
 
-def process(proc_data):
+def _process(proc_data):
     """
     Final processing to conform to the schema.
 
@@ -116,26 +134,7 @@ def process(proc_data):
 
     Returns:
 
-        List of Dictionaries. Structured data with the following schema:
-
-        [
-          {
-            "destination":     string,
-            "gateway":         string,
-            "genmask":         string,
-            "flags":           string,
-            "flags_pretty": [
-                               string,
-            ]
-            "metric":          integer,
-            "ref":             integer,
-            "use":             integer,
-            "mss":             integer,
-            "window":          integer,
-            "irtt":            integer,
-            "iface":           string
-          }
-        ]
+        List of Dictionaries. Structured data to conform to the schema.
     """
     for entry in proc_data:
         int_list = ['metric', 'ref', 'use', 'mss', 'window', 'irtt']
@@ -207,4 +206,4 @@ def parse(data, raw=False, quiet=False):
     if raw:
         return raw_output
     else:
-        return process(raw_output)
+        return _process(raw_output)
