@@ -1,6 +1,6 @@
 """jc - JSON CLI output utility `timedatectl` command output parser
 
-The `epoch_utc` calculated timestamp field is timezone-aware and is only available if the universal_time field is available.
+The `epoch_utc` calculated timestamp field is timezone-aware and is only available if the `universal_time` field is available.
 
 Usage (cli):
 
@@ -15,9 +15,21 @@ Usage (module):
     import jc.parsers.timedatectl
     result = jc.parsers.timedatectl.parse(timedatectl_command_output)
 
-Compatibility:
+Schema:
 
-    'linux'
+    {
+      "local_time":                        string,
+      "universal_time":                    string,
+      "epoch_utc":                         integer,     # timezone-aware timestamp
+      "rtc_time":                          string,
+      "time_zone":                         string,
+      "ntp_enabled":                       boolean,
+      "ntp_synchronized":                  boolean,
+      "system_clock_synchronized":         boolean,
+      "systemd-timesyncd.service_active":  boolean,
+      "rtc_in_local_tz":                   boolean,
+      "dst_active":                        boolean
+    }
 
 Examples:
 
@@ -50,7 +62,8 @@ import jc.utils
 
 
 class info():
-    version = '1.2'
+    """Provides parser metadata (version, author, etc.)"""
+    version = '1.3'
     description = '`timedatectl status` command parser'
     author = 'Kelly Brazil'
     author_email = 'kellyjonbrazil@gmail.com'
@@ -64,7 +77,7 @@ class info():
 __version__ = info.version
 
 
-def process(proc_data):
+def _process(proc_data):
     """
     Final processing to conform to the schema.
 
@@ -74,21 +87,7 @@ def process(proc_data):
 
     Returns:
 
-        Dictionary. Structured data with the following schema:
-
-        {
-          "local_time":                        string,
-          "universal_time":                    string,
-          "epoch_utc":                         integer,     # timezone-aware timestamp
-          "rtc_time":                          string,
-          "time_zone":                         string,
-          "ntp_enabled":                       boolean,
-          "ntp_synchronized":                  boolean,
-          "system_clock_synchronized":         boolean,
-          "systemd-timesyncd.service_active":  boolean,
-          "rtc_in_local_tz":                   boolean,
-          "dst_active":                        boolean
-        }
+        Dictionary. Structured data to conform to the schema.
     """
     # boolean changes
     bool_list = ['ntp_enabled', 'ntp_synchronized', 'rtc_in_local_tz', 'dst_active',
@@ -138,4 +137,4 @@ def parse(data, raw=False, quiet=False):
     if raw:
         return raw_output
     else:
-        return process(raw_output)
+        return _process(raw_output)
