@@ -17,9 +17,22 @@ Usage (module):
     import jc.parsers.who
     result = jc.parsers.who.parse(who_command_output)
 
-Compatibility:
+Schema:
 
-    'linux', 'darwin', 'cygwin', 'aix', 'freebsd'
+    [
+      {
+        "user":            string,
+        "event":           string,
+        "writeable_tty":   string,
+        "tty":             string,
+        "time":            string,
+        "epoch":           integer,     # naive timestamp. null if time cannot be converted
+        "idle":            string,
+        "pid":             integer,
+        "from":            string,
+        "comment":         string
+      }
+    ]
 
 Examples:
 
@@ -119,7 +132,8 @@ import jc.utils
 
 
 class info():
-    version = '1.2'
+    """Provides parser metadata (version, author, etc.)"""
+    version = '1.3'
     description = '`who` command parser'
     author = 'Kelly Brazil'
     author_email = 'kellyjonbrazil@gmail.com'
@@ -133,7 +147,7 @@ class info():
 __version__ = info.version
 
 
-def process(proc_data):
+def _process(proc_data):
     """
     Final processing to conform to the schema.
 
@@ -143,22 +157,7 @@ def process(proc_data):
 
     Returns:
 
-        List of Dictionaries. Structured data with the following schema:
-
-        [
-          {
-            "user":            string,
-            "event":           string,
-            "writeable_tty":   string,
-            "tty":             string,
-            "time":            string,
-            "epoch":           integer,     # naive timestamp. null if time cannot be converted
-            "idle":            string,
-            "pid":             integer,
-            "from":            string,
-            "comment":         string
-          }
-        ]
+        List of Dictionaries. Structured data to conform to the schema.
     """
     for entry in proc_data:
         int_list = ['pid']
@@ -302,4 +301,4 @@ def parse(data, raw=False, quiet=False):
     if raw:
         return raw_output
     else:
-        return process(raw_output)
+        return _process(raw_output)
